@@ -19,6 +19,7 @@ import base64
 import binascii
 from decimal import ROUND_HALF_UP, Decimal, localcontext
 from distutils.util import strtobool
+from enum import Enum
 from typing import TYPE_CHECKING, Any
 
 from aiohomekit.exceptions import CharacteristicPermissionError, FormatError
@@ -60,6 +61,16 @@ NUMBER_TYPES = INTEGER_TYPES + [CharacteristicFormats.float]
 
 
 class Characteristic:
+
+    type: str
+    iid: int
+    perms: list[str]
+    minValue: int | float | None
+    maxValue: int | float | None
+    minStep: int | float | None
+
+    service: Service
+
     def __init__(self, service: Service, characteristic_type: str, **kwargs) -> None:
         self.service = service
         self.iid = service.accessory.get_next_id()
@@ -133,20 +144,20 @@ class Characteristic:
     def available(self) -> bool:
         return self._status != HapStatusCode.UNABLE_TO_COMMUNICATE
 
-    def set_events(self, new_val):
+    def set_events(self, new_val: Any) -> None:
         self.ev = new_val
 
-    def set_value(self, new_val):
+    def set_value(self, new_val: Any) -> None:
         """
         This function sets the value of this characteristic.
         """
         self._value = new_val
 
     @property
-    def value(self):
-        if self.format == CharacteristicFormats.tlv8:
-            extra_data = characteristics.get(self.type, {})
+    def value(self) -> Any:
+        extra_data = characteristics.get(self.type, {})
 
+        if self.format == CharacteristicFormats.tlv8:
             new_val = base64.b64decode(self._value)
             struct = extra_data.get("struct")
             if struct:
@@ -155,13 +166,19 @@ class Characteristic:
                 else:
                     return struct.decode(new_val)
 
+        if enum := extra_data.get("enum"):
+            return enum(self._value)
+
         return self._value
 
     @value.setter
-    def value(self, value):
+    def value(self, value: Any) -> None:
         self.set_value(value)
 
-    def validate_value(self, new_val):
+    def validate_value(self, new_val: Any) -> Any:
+        if isinstance(new_val, Enum):
+            new_val = new_val.value
+
         try:
             # convert input to python int if it is any kind of int
             if self.format in [
@@ -226,7 +243,7 @@ class Characteristic:
 
         return new_val
 
-    def get_value(self):
+    def get_value(self) -> Any:
         """
         This method returns the value of this characteristic. Permissions are checked first, then either the callback
         for getting the values is executed (execution time may vary) or the value is directly returned if not callback
